@@ -60,7 +60,7 @@ bisection <- function(f, a, b, tol = 1e-3, m = 100) {
     while (abs(b - a) > tol) {
         iter <- iter + 1
         if (iter > m) {
-            warning("maximum number of iterations exceeded")
+            warning("iterations maximum exceeded")
             break
         }
         xmid <- (a + b) / 2
